@@ -16,6 +16,7 @@
 #include "certifycertificatecommand.h"
 #include "kleopatra_debug.h"
 
+#include <Libkleo/Algorithm>
 #include <Libkleo/KeyList>
 #include <Libkleo/KeyListSortFilterProxyModel>
 #include <Libkleo/KeyCache>
@@ -92,9 +93,9 @@ protected:
         const QString fpr = index.data(KeyList::FingerprintRole).toString();
         // find information:
         const std::vector<Import>::const_iterator it
-            = qBinaryFind(m_importsByFingerprint.begin(), m_importsByFingerprint.end(),
-                          fpr.toLatin1().constData(),
-                          ByImportFingerprint<std::less>());
+            = Kleo::binary_find(m_importsByFingerprint.begin(), m_importsByFingerprint.end(),
+                                fpr.toLatin1().constData(),
+                                ByImportFingerprint<std::less>());
         if (it == m_importsByFingerprint.end()) {
             return AbstractKeyListSortFilterProxyModel::data(index, role);
         } else {
@@ -507,7 +508,7 @@ void ImportCertificatesCommand::Private::handleExternalCMSImports()
     // For external CMS Imports we have to manually do a keylist
     // with validation to get the intermediate and root ca imported
     // automatically if trusted-certs and extra-certs are used.
-    for (const ImportResult &result : qAsConst(results)) {
+    for (const ImportResult &result : std::as_const(results)) {
         const auto imports = result.imports();
         for (const Import &import : imports) {
             if (!import.fingerprint()) {
