@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef DIRSERVCONFIGPAGE_H
-#define DIRSERVCONFIGPAGE_H
+#pragma once
 
 #include <KCModule>
 
@@ -16,6 +15,7 @@
 
 class QCheckBox;
 class QLabel;
+class QLineEdit;
 class QTimeEdit;
 class QSpinBox;
 namespace Kleo
@@ -54,19 +54,19 @@ private:
                                            EntryMultiplicity multiplicity,
                                            ShowError showError);
 
-    Kleo::DirectoryServicesWidget *mWidget;
-    QTimeEdit *mTimeout;
-    QSpinBox *mMaxItems;
-    QLabel *mMaxItemsLabel;
-    QCheckBox *mAddNewServersCB;
+private:
+    QLineEdit *mOpenPGPKeyserverEdit = nullptr;
+    Kleo::DirectoryServicesWidget *mWidget = nullptr;
+    QTimeEdit *mTimeout = nullptr;
+    QSpinBox *mMaxItems = nullptr;
+    QLabel *mMaxItemsLabel = nullptr;
+    QCheckBox *mAddNewServersCB = nullptr;
 
-    QGpgME::CryptoConfigEntry *mX509ServicesEntry;
-    QGpgME::CryptoConfigEntry *mOpenPGPServiceEntry;
-    QGpgME::CryptoConfigEntry *mTimeoutConfigEntry;
-    QGpgME::CryptoConfigEntry *mMaxItemsConfigEntry;
-    QGpgME::CryptoConfigEntry *mAddNewServersConfigEntry;
+    QGpgME::CryptoConfigEntry *mX509ServicesEntry = nullptr;
+    QGpgME::CryptoConfigEntry *mOpenPGPServiceEntry = nullptr;
+    QGpgME::CryptoConfigEntry *mTimeoutConfigEntry = nullptr;
+    QGpgME::CryptoConfigEntry *mMaxItemsConfigEntry = nullptr;
+    QGpgME::CryptoConfigEntry *mAddNewServersConfigEntry = nullptr;
 
-    QGpgME::CryptoConfig *mConfig;
+    QGpgME::CryptoConfig *mConfig = nullptr;
 };
-
-#endif
