@@ -8,11 +8,12 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CONF_GROUPSCONFIGDIALOG_H__
-#define __KLEOPATRA_CONF_GROUPSCONFIGDIALOG_H__
+#pragma once
 
 #include <KConfigDialog>
 
+#include <memory>
+
 class GroupsConfigDialog : public KConfigDialog
 {
     Q_OBJECT
@@ -34,4 +35,3 @@ private:
     const std::unique_ptr<Private> d;
 };
 
-#endif /* __KLEOPATRA_CONF_GROUPSCONFIGDIALOG_H__ */
