@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CONF_SMIMEVALIDATIONCONFIGURATIONWIDGET_H__
-#define __KLEOPATRA_CONF_SMIMEVALIDATIONCONFIGURATIONWIDGET_H__
+#pragma once
 
 #include <QWidget>
 
@@ -43,4 +42,3 @@ private:
 }
 }
 
-#endif /* __KLEOPATRA_CONF_SMIMEVALIDATIONCONFIGURATIONWIDGET_H__ */
