@@ -10,8 +10,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_SIGNENCRYPTFILESWIZARD_H__
-#define __KLEOPATRA_CRYPTO_GUI_SIGNENCRYPTFILESWIZARD_H__
+#pragma once
 
 #include <utils/pimpl_ptr.h>
 
@@ -102,4 +101,3 @@ private:
 
 }
 
-#endif /* __KLEOPATRA_CRYPTO_GUI_SIGNENCRYPTFILESWIZARD_H__ */
