@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_DIALOGS_ADDEMAILDIALOG_H__
-#define __KLEOPATRA_DIALOGS_ADDEMAILDIALOG_H__
+#pragma once
 
 #include <QDialog>
 
@@ -39,4 +38,3 @@ private:
 
 }
 }
-#endif
