@@ -8,11 +8,11 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_DIALOGS_EDITGROUPDIALOG_H__
-#define __KLEOPATRA_DIALOGS_EDITGROUPDIALOG_H__
+#pragma once
 
 #include <QDialog>
 
+#include <memory>
 #include <vector>
 
 namespace GpgME
@@ -53,4 +53,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_DIALOGS_EDITGROUPDIALOG_H__
