@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UTILS_HEADERVIEW_H__
-#define __KLEOPATRA_UTILS_HEADERVIEW_H__
+#pragma once
 
 #include <QHeaderView>
 
@@ -29,7 +28,6 @@ public:
     void setSectionSizes(const std::vector<int> &sizes);
     std::vector<int> sectionSizes() const;
 
-    void setSectionResizeMode(unsigned int logicalIndex, ResizeMode mode);
 private:
     //@{
     /*! Defined, but not implemented, to catch at least some usage errors */
@@ -44,4 +42,3 @@ private:
 
 }
 
-#endif /* __KLEOPATRA_UTILS_HEADERVIEW_H__ */
